ImageInfo class

What a screenshot has to satisfy, read straight out of the file header.

Constructors

ImageInfo({required int width, required int height, required bool hasAlpha})
const

Properties

hasAlpha bool
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited