PlayLocaleMetadata class

One locale's Play listing.

Constructors

PlayLocaleMetadata(String locale)

Properties

hashCode int
The hash code for this object.
no setterinherited
images Map<String, List<File>>
Directory name under images/ -> the files in it, in publish order.
final
locale String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text Map<String, String>
title, short_description, full_description, as stored.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited