defaultLanguage property

String? defaultLanguage
getter/setter pair

From details/default_language.txt. Play has a distinguished locale and the App Store has no equivalent, so this has no counterpart in AppStoreMetadata.

Implementation

String? defaultLanguage;