AppStoreMetadata class

Constructors

AppStoreMetadata()

Properties

ageRating Map<String, Object?>?
ageRatingDeclarations attributes, straight from age-rating.json.
getter/setter pair
categories Map<String, String>
appInfos relationships: primaryCategory, secondaryCategory. Values are appCategories ids such as HEALTH_AND_FITNESS.
final
contentRights String?
apps.contentRightsDeclaration, from info/content_rights.txt.
getter/setter pair
appStoreVersions.copyright, from info/copyright.txt.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
locales List<LocaleMetadata>
final
reviewNotes String?
appStoreReviewDetails.notes, from review-notes.md.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited