PlayMetadata class
A Play listing tree.
Constructors
- PlayMetadata(String path)
Properties
- defaultLanguage ↔ String?
-
From
details/default_language.txt. Play has a distinguished locale and the App Store has no equivalent, so this has no counterpart in AppStoreMetadata.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
-
locales
→ List<
PlayLocaleMetadata> -
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited