NotesText class
Notes to publish.
Properties
- fromVersion → String
-
The version the text was taken from, which is not the version being
released when an older section had to be fallen back to. Callers say so
out loud rather than quietly publishing another version's notes.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override